# Copyright 2023 The GoPlus. All rights reserved.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from goplus.base import Base
from swagger_client.api.token_controller_v_1_api import TokenControllerV1Api


class Token(Base):
    """
    Token Security
    """

    def __init__(self, access_token=None):
        super().__init__(access_token=access_token)
        self.api = TokenControllerV1Api()

    @staticmethod
    def __check(addresses):

        if not isinstance(addresses, list):
            raise TypeError("contract_addresses must be of list type!")

        if len(addresses) == 0:
            raise ValueError("invalid contract_addresses")

    def token_security(self, chain_id: str, addresses: list, **kwargs):

        self.__check(addresses)

        return self.api.token_security_using_get1(
            chain_id=chain_id,
            contract_addresses=",".join(addresses),
            **self.authorization,
            **kwargs
        )



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AuditInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'audit_firm': 'str',
        'audit_link': 'str',
        'audit_time': 'str'
    }

    attribute_map = {
        'audit_firm': 'audit_firm',
        'audit_link': 'audit_link',
        'audit_time': 'audit_time'
    }

    def __init__(self, audit_firm=None, audit_link=None, audit_time=None):  # noqa: E501
        """AuditInfo - a model defined in Swagger"""  # noqa: E501
        self._audit_firm = None
        self._audit_link = None
        self._audit_time = None
        self.discriminator = None
        if audit_firm is not None:
            self.audit_firm = audit_firm
        if audit_link is not None:
            self.audit_link = audit_link
        if audit_time is not None:
            self.audit_time = audit_time

    @property
    def audit_firm(self):
        """Gets the audit_firm of this AuditInfo.  # noqa: E501

        It describes the firm that audited the dApp.  # noqa: E501

        :return: The audit_firm of this AuditInfo.  # noqa: E501
        :rtype: str
        """
        return self._audit_firm

    @audit_firm.setter
    def audit_firm(self, audit_firm):
        """Sets the audit_firm of this AuditInfo.

        It describes the firm that audited the dApp.  # noqa: E501

        :param audit_firm: The audit_firm of this AuditInfo.  # noqa: E501
        :type: str
        """

        self._audit_firm = audit_firm

    @property
    def audit_link(self):
        """Gets the audit_link of this AuditInfo.  # noqa: E501

        It describes the website link of the audit report.  # noqa: E501

        :return: The audit_link of this AuditInfo.  # noqa: E501
        :rtype: str
        """
        return self._audit_link

    @audit_link.setter
    def audit_link(self, audit_link):
        """Sets the audit_link of this AuditInfo.

        It describes the website link of the audit report.  # noqa: E501

        :param audit_link: The audit_link of this AuditInfo.  # noqa: E501
        :type: str
        """

        self._audit_link = audit_link

    @property
    def audit_time(self):
        """Gets the audit_time of this AuditInfo.  # noqa: E501

        It describes the time shown in the latest audit report.  # noqa: E501

        :return: The audit_time of this AuditInfo.  # noqa: E501
        :rtype: str
        """
        return self._audit_time

    @audit_time.setter
    def audit_time(self, audit_time):
        """Sets the audit_time of this AuditInfo.

        It describes the time shown in the latest audit report.  # noqa: E501

        :param audit_time: The audit_time of this AuditInfo.  # noqa: E501
        :type: str
        """

        self._audit_time = audit_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AuditInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResponseWrapperPhishingSiteResultNftRisk(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'nft_open_source': 'int',
        'privileged_minting': 'ResponseWrapperPhishingSiteResultNftRiskPrivilegedMinting',
        'oversupply_minting': 'int',
        'nft_proxy': 'int',
        'restricted_approval': 'int',
        'transfer_without_approval': 'ResponseWrapperPhishingSiteResultNftRiskTransferWithoutApproval',
        'privileged_burn': 'ResponseWrapperPhishingSiteResultNftRiskPrivilegedBurn',
        'self_destruct': 'ResponseWrapperPhishingSiteResultNftRiskSelfDestruct'
    }

    attribute_map = {
        'nft_open_source': 'nft_open_source',
        'privileged_minting': 'privileged_minting',
        'oversupply_minting': 'oversupply_minting',
        'nft_proxy': 'nft_proxy',
        'restricted_approval': 'restricted_approval',
        'transfer_without_approval': 'transfer_without_approval',
        'privileged_burn': 'privileged_burn',
        'self_destruct': 'self_destruct'
    }

    def __init__(self, nft_open_source=None, privileged_minting=None, oversupply_minting=None, nft_proxy=None, restricted_approval=None, transfer_without_approval=None, privileged_burn=None, self_destruct=None):  # noqa: E501
        """ResponseWrapperPhishingSiteResultNftRisk - a model defined in Swagger"""  # noqa: E501
        self._nft_open_source = None
        self._privileged_minting = None
        self._oversupply_minting = None
        self._nft_proxy = None
        self._restricted_approval = None
        self._transfer_without_approval = None
        self._privileged_burn = None
        self._self_destruct = None
        self.discriminator = None
        if nft_open_source is not None:
            self.nft_open_source = nft_open_source
        if privileged_minting is not None:
            self.privileged_minting = privileged_minting
        if oversupply_minting is not None:
            self.oversupply_minting = oversupply_minting
        if nft_proxy is not None:
            self.nft_proxy = nft_proxy
        if restricted_approval is not None:
            self.restricted_approval = restricted_approval
        if transfer_without_approval is not None:
            self.transfer_without_approval = transfer_without_approval
        if privileged_burn is not None:
            self.privileged_burn = privileged_burn
        if self_destruct is not None:
            self.self_destruct = self_destruct

    @property
    def nft_open_source(self):
        """Gets the nft_open_source of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501

        It describes whether this contract is open source.  \"1\" means true;  \"0\" means false.(Notice:Un-open-sourced contracts may hide various unknown mechanisms and are extremely risky. When the contract is not open source, we will not be able to detect other risk items.)  # noqa: E501

        :return: The nft_open_source of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :rtype: int
        """
        return self._nft_open_source

    @nft_open_source.setter
    def nft_open_source(self, nft_open_source):
        """Sets the nft_open_source of this ResponseWrapperPhishingSiteResultNftRisk.

        It describes whether this contract is open source.  \"1\" means true;  \"0\" means false.(Notice:Un-open-sourced contracts may hide various unknown mechanisms and are extremely risky. When the contract is not open source, we will not be able to detect other risk items.)  # noqa: E501

        :param nft_open_source: The nft_open_source of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :type: int
        """

        self._nft_open_source = nft_open_source

    @property
    def privileged_minting(self):
        """Gets the privileged_minting of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501


        :return: The privileged_minting of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :rtype: ResponseWrapperPhishingSiteResultNftRiskPrivilegedMinting
        """
        return self._privileged_minting

    @privileged_minting.setter
    def privileged_minting(self, privileged_minting):
        """Sets the privileged_minting of this ResponseWrapperPhishingSiteResultNftRisk.


        :param privileged_minting: The privileged_minting of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :type: ResponseWrapperPhishingSiteResultNftRiskPrivilegedMinting
        """

        self._privileged_minting = privileged_minting

    @property
    def oversupply_minting(self):
        """Gets the oversupply_minting of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501

        It describes whether this NFT owner can bypass the maximum amount of minting specified in the contract, and continue to mint NFTs beyond this limit.  \"1\" means true;  \"0\" means false;  \"Null\" means unknown.(Notice:Oversupply minting refers to the existence of a special mint method in the NFT contract - the owner can bypass the maximum amount of minting specified in the contract, and continue to mint NFTs beyond this limit.)  # noqa: E501

        :return: The oversupply_minting of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :rtype: int
        """
        return self._oversupply_minting

    @oversupply_minting.setter
    def oversupply_minting(self, oversupply_minting):
        """Sets the oversupply_minting of this ResponseWrapperPhishingSiteResultNftRisk.

        It describes whether this NFT owner can bypass the maximum amount of minting specified in the contract, and continue to mint NFTs beyond this limit.  \"1\" means true;  \"0\" means false;  \"Null\" means unknown.(Notice:Oversupply minting refers to the existence of a special mint method in the NFT contract - the owner can bypass the maximum amount of minting specified in the contract, and continue to mint NFTs beyond this limit.)  # noqa: E501

        :param oversupply_minting: The oversupply_minting of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :type: int
        """

        self._oversupply_minting = oversupply_minting

    @property
    def nft_proxy(self):
        """Gets the nft_proxy of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501

        It describes whether this NFT contract has a proxy contract.  \"1\" means true;  \"0\" means false;  \"Null\" means unknown.(Notice:(1) When \"is_open_source\":\"0\", it will return \"null\". (2) Most Proxy contracts are accompanied by modifiable implementation contracts, and implementation contracts may contain significant potential risk.)  # noqa: E501

        :return: The nft_proxy of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :rtype: int
        """
        return self._nft_proxy

    @nft_proxy.setter
    def nft_proxy(self, nft_proxy):
        """Sets the nft_proxy of this ResponseWrapperPhishingSiteResultNftRisk.

        It describes whether this NFT contract has a proxy contract.  \"1\" means true;  \"0\" means false;  \"Null\" means unknown.(Notice:(1) When \"is_open_source\":\"0\", it will return \"null\". (2) Most Proxy contracts are accompanied by modifiable implementation contracts, and implementation contracts may contain significant potential risk.)  # noqa: E501

        :param nft_proxy: The nft_proxy of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :type: int
        """

        self._nft_proxy = nft_proxy

    @property
    def restricted_approval(self):
        """Gets the restricted_approval of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501

        It describes whether the NFT contract can restrict the approval, resulting in NFT can not be traded on the NFT DEX. \"1\" means true;  \"0\" means false;  \"Null\" means unknown.(Notice:If this risk exists, it means that users will not be able to trade the NFT on the exchange and only privileged users in the whitelist will be able to trade normally.)  # noqa: E501

        :return: The restricted_approval of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :rtype: int
        """
        return self._restricted_approval

    @restricted_approval.setter
    def restricted_approval(self, restricted_approval):
        """Sets the restricted_approval of this ResponseWrapperPhishingSiteResultNftRisk.

        It describes whether the NFT contract can restrict the approval, resulting in NFT can not be traded on the NFT DEX. \"1\" means true;  \"0\" means false;  \"Null\" means unknown.(Notice:If this risk exists, it means that users will not be able to trade the NFT on the exchange and only privileged users in the whitelist will be able to trade normally.)  # noqa: E501

        :param restricted_approval: The restricted_approval of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :type: int
        """

        self._restricted_approval = restricted_approval

    @property
    def transfer_without_approval(self):
        """Gets the transfer_without_approval of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501


        :return: The transfer_without_approval of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :rtype: ResponseWrapperPhishingSiteResultNftRiskTransferWithoutApproval
        """
        return self._transfer_without_approval

    @transfer_without_approval.setter
    def transfer_without_approval(self, transfer_without_approval):
        """Sets the transfer_without_approval of this ResponseWrapperPhishingSiteResultNftRisk.


        :param transfer_without_approval: The transfer_without_approval of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :type: ResponseWrapperPhishingSiteResultNftRiskTransferWithoutApproval
        """

        self._transfer_without_approval = transfer_without_approval

    @property
    def privileged_burn(self):
        """Gets the privileged_burn of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501


        :return: The privileged_burn of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :rtype: ResponseWrapperPhishingSiteResultNftRiskPrivilegedBurn
        """
        return self._privileged_burn

    @privileged_burn.setter
    def privileged_burn(self, privileged_burn):
        """Sets the privileged_burn of this ResponseWrapperPhishingSiteResultNftRisk.


        :param privileged_burn: The privileged_burn of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :type: ResponseWrapperPhishingSiteResultNftRiskPrivilegedBurn
        """

        self._privileged_burn = privileged_burn

    @property
    def self_destruct(self):
        """Gets the self_destruct of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501


        :return: The self_destruct of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :rtype: ResponseWrapperPhishingSiteResultNftRiskSelfDestruct
        """
        return self._self_destruct

    @self_destruct.setter
    def self_destruct(self, self_destruct):
        """Sets the self_destruct of this ResponseWrapperPhishingSiteResultNftRisk.


        :param self_destruct: The self_destruct of this ResponseWrapperPhishingSiteResultNftRisk.  # noqa: E501
        :type: ResponseWrapperPhishingSiteResultNftRiskSelfDestruct
        """

        self._self_destruct = self_destruct

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResponseWrapperPhishingSiteResultNftRisk, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseWrapperPhishingSiteResultNftRisk):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResponseWrapperTokenSecurityFakeToken(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'true_token_address': 'str',
        'value': 'int'
    }

    attribute_map = {
        'true_token_address': 'true_token_address',
        'value': 'value'
    }

    def __init__(self, true_token_address=None, value=None):  # noqa: E501
        """ResponseWrapperTokenSecurityFakeToken - a model defined in Swagger"""  # noqa: E501
        self._true_token_address = None
        self._value = None
        self.discriminator = None
        if true_token_address is not None:
            self.true_token_address = true_token_address
        if value is not None:
            self.value = value

    @property
    def true_token_address(self):
        """Gets the true_token_address of this ResponseWrapperTokenSecurityFakeToken.  # noqa: E501

        If the value is set to 1, and true_token_address is the address of the authentic mainstream asset that the token is imitating on this public chain. If there are multiple mainstream assets with the same name, they will be separated by commas.  # noqa: E501

        :return: The true_token_address of this ResponseWrapperTokenSecurityFakeToken.  # noqa: E501
        :rtype: str
        """
        return self._true_token_address

    @true_token_address.setter
    def true_token_address(self, true_token_address):
        """Sets the true_token_address of this ResponseWrapperTokenSecurityFakeToken.

        If the value is set to 1, and true_token_address is the address of the authentic mainstream asset that the token is imitating on this public chain. If there are multiple mainstream assets with the same name, they will be separated by commas.  # noqa: E501

        :param true_token_address: The true_token_address of this ResponseWrapperTokenSecurityFakeToken.  # noqa: E501
        :type: str
        """

        self._true_token_address = true_token_address

    @property
    def value(self):
        """Gets the value of this ResponseWrapperTokenSecurityFakeToken.  # noqa: E501

        If the value is set to 1, and true_token_address is the address of the authentic mainstream asset that the token is imitating on this public chain. If there are multiple mainstream assets with the same name, they will be separated by commas.  # noqa: E501

        :return: The value of this ResponseWrapperTokenSecurityFakeToken.  # noqa: E501
        :rtype: int
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ResponseWrapperTokenSecurityFakeToken.

        If the value is set to 1, and true_token_address is the address of the authentic mainstream asset that the token is imitating on this public chain. If there are multiple mainstream assets with the same name, they will be separated by commas.  # noqa: E501

        :param value: The value of this ResponseWrapperTokenSecurityFakeToken.  # noqa: E501
        :type: int
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResponseWrapperTokenSecurityFakeToken, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseWrapperTokenSecurityFakeToken):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResponseWrapperPhishingSiteResultWebsiteContractSecurity(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'standard': 'str',
        'is_contract': 'int',
        'address_risk': 'list[str]',
        'contract': 'str',
        'is_open_source': 'int',
        'nft_risk': 'ResponseWrapperPhishingSiteResultNftRisk'
    }

    attribute_map = {
        'standard': 'standard',
        'is_contract': 'is_contract',
        'address_risk': 'address_risk',
        'contract': 'contract',
        'is_open_source': 'is_open_source',
        'nft_risk': 'nft_risk'
    }

    def __init__(self, standard=None, is_contract=None, address_risk=None, contract=None, is_open_source=None, nft_risk=None):  # noqa: E501
        """ResponseWrapperPhishingSiteResultWebsiteContractSecurity - a model defined in Swagger"""  # noqa: E501
        self._standard = None
        self._is_contract = None
        self._address_risk = None
        self._contract = None
        self._is_open_source = None
        self._nft_risk = None
        self.discriminator = None
        if standard is not None:
            self.standard = standard
        if is_contract is not None:
            self.is_contract = is_contract
        if address_risk is not None:
            self.address_risk = address_risk
        if contract is not None:
            self.contract = contract
        if is_open_source is not None:
            self.is_open_source = is_open_source
        if nft_risk is not None:
            self.nft_risk = nft_risk

    @property
    def standard(self):
        """Gets the standard of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501

        contract type(erc20, erc721, erc1155)  # noqa: E501

        :return: The standard of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501
        :rtype: str
        """
        return self._standard

    @standard.setter
    def standard(self, standard):
        """Sets the standard of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.

        contract type(erc20, erc721, erc1155)  # noqa: E501

        :param standard: The standard of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501
        :type: str
        """

        self._standard = standard

    @property
    def is_contract(self):
        """Gets the is_contract of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501

        It describes whether the holder is a contract \"1\" means true; \"0\" means false.  # noqa: E501

        :return: The is_contract of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501
        :rtype: int
        """
        return self._is_contract

    @is_contract.setter
    def is_contract(self, is_contract):
        """Sets the is_contract of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.

        It describes whether the holder is a contract \"1\" means true; \"0\" means false.  # noqa: E501

        :param is_contract: The is_contract of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501
        :type: int
        """

        self._is_contract = is_contract

    @property
    def address_risk(self):
        """Gets the address_risk of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501

        address risk  # noqa: E501

        :return: The address_risk of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501
        :rtype: list[str]
        """
        return self._address_risk

    @address_risk.setter
    def address_risk(self, address_risk):
        """Sets the address_risk of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.

        address risk  # noqa: E501

        :param address_risk: The address_risk of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501
        :type: list[str]
        """

        self._address_risk = address_risk

    @property
    def contract(self):
        """Gets the contract of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501

        contract address  # noqa: E501

        :return: The contract of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501
        :rtype: str
        """
        return self._contract

    @contract.setter
    def contract(self, contract):
        """Sets the contract of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.

        contract address  # noqa: E501

        :param contract: The contract of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501
        :type: str
        """

        self._contract = contract

    @property
    def is_open_source(self):
        """Gets the is_open_source of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501

        It describes whether this contract is open source.  \"1\" means true;  \"0\" means false.(Notice:Un-open-sourced contracts may hide various unknown mechanisms and are extremely risky. When the contract is not open source, we will not be able to detect other risk items.)  # noqa: E501

        :return: The is_open_source of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501
        :rtype: int
        """
        return self._is_open_source

    @is_open_source.setter
    def is_open_source(self, is_open_source):
        """Sets the is_open_source of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.

        It describes whether this contract is open source.  \"1\" means true;  \"0\" means false.(Notice:Un-open-sourced contracts may hide various unknown mechanisms and are extremely risky. When the contract is not open source, we will not be able to detect other risk items.)  # noqa: E501

        :param is_open_source: The is_open_source of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501
        :type: int
        """

        self._is_open_source = is_open_source

    @property
    def nft_risk(self):
        """Gets the nft_risk of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501


        :return: The nft_risk of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501
        :rtype: ResponseWrapperPhishingSiteResultNftRisk
        """
        return self._nft_risk

    @nft_risk.setter
    def nft_risk(self, nft_risk):
        """Sets the nft_risk of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.


        :param nft_risk: The nft_risk of this ResponseWrapperPhishingSiteResultWebsiteContractSecurity.  # noqa: E501
        :type: ResponseWrapperPhishingSiteResultNftRisk
        """

        self._nft_risk = nft_risk

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResponseWrapperPhishingSiteResultWebsiteContractSecurity, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseWrapperPhishingSiteResultWebsiteContractSecurity):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    GoPlus Security API Document

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ResponseWrapperTokenSecurityNFTList(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'nft_percentage': 'str',
        'nft_id': 'str',
        'amount': 'str',
        'in_effect': 'str',
        'value': 'str'
    }

    attribute_map = {
        'nft_percentage': 'NFT_percentage',
        'nft_id': 'NFT_id',
        'amount': 'amount',
        'in_effect': 'in_effect',
        'value': 'value'
    }

    def __init__(self, nft_percentage=None, nft_id=None, amount=None, in_effect=None, value=None):  # noqa: E501
        """ResponseWrapperTokenSecurityNFTList - a model defined in Swagger"""  # noqa: E501
        self._nft_percentage = None
        self._nft_id = None
        self._amount = None
        self._in_effect = None
        self._value = None
        self.discriminator = None
        if nft_percentage is not None:
            self.nft_percentage = nft_percentage
        if nft_id is not None:
            self.nft_id = nft_id
        if amount is not None:
            self.amount = amount
        if in_effect is not None:
            self.in_effect = in_effect
        if value is not None:
            self.value = value

    @property
    def nft_percentage(self):
        """Gets the nft_percentage of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501

        \"NFT_percentage\" represents the proportion of that NFT in the total liquidity. When the LP holder is a lockup address, this information will also appear in the \"locked_detail\" section.  # noqa: E501

        :return: The nft_percentage of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501
        :rtype: str
        """
        return self._nft_percentage

    @nft_percentage.setter
    def nft_percentage(self, nft_percentage):
        """Sets the nft_percentage of this ResponseWrapperTokenSecurityNFTList.

        \"NFT_percentage\" represents the proportion of that NFT in the total liquidity. When the LP holder is a lockup address, this information will also appear in the \"locked_detail\" section.  # noqa: E501

        :param nft_percentage: The nft_percentage of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501
        :type: str
        """

        self._nft_percentage = nft_percentage

    @property
    def nft_id(self):
        """Gets the nft_id of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501

        \"NFT_id\" is the NFTID corresponding to that NFT.   # noqa: E501

        :return: The nft_id of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501
        :rtype: str
        """
        return self._nft_id

    @nft_id.setter
    def nft_id(self, nft_id):
        """Sets the nft_id of this ResponseWrapperTokenSecurityNFTList.

        \"NFT_id\" is the NFTID corresponding to that NFT.   # noqa: E501

        :param nft_id: The nft_id of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501
        :type: str
        """

        self._nft_id = nft_id

    @property
    def amount(self):
        """Gets the amount of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501

        \"amount\" is the liquidity quantity corresponding to the NFT.  # noqa: E501

        :return: The amount of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501
        :rtype: str
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this ResponseWrapperTokenSecurityNFTList.

        \"amount\" is the liquidity quantity corresponding to the NFT.  # noqa: E501

        :param amount: The amount of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501
        :type: str
        """

        self._amount = amount

    @property
    def in_effect(self):
        """Gets the in_effect of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501

        \"in_effect\" indicates whether the liquidity corresponding to that NFT is effective at the current price.   # noqa: E501

        :return: The in_effect of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501
        :rtype: str
        """
        return self._in_effect

    @in_effect.setter
    def in_effect(self, in_effect):
        """Sets the in_effect of this ResponseWrapperTokenSecurityNFTList.

        \"in_effect\" indicates whether the liquidity corresponding to that NFT is effective at the current price.   # noqa: E501

        :param in_effect: The in_effect of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501
        :type: str
        """

        self._in_effect = in_effect

    @property
    def value(self):
        """Gets the value of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501

        \"value\" is the total USD value corresponding to the NFT.  # noqa: E501

        :return: The value of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ResponseWrapperTokenSecurityNFTList.

        \"value\" is the total USD value corresponding to the NFT.  # noqa: E501

        :param value: The value of this ResponseWrapperTokenSecurityNFTList.  # noqa: E501
        :type: str
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResponseWrapperTokenSecurityNFTList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseWrapperTokenSecurityNFTList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
